@@ -79,7 +79,7 @@ class AccountModel : public QAbstractListModel
         QHash<AccountModel::Role, QVariant> m_newUserData;
         QHash<QString, OrgFreedesktopAccountsUserInterface*> m_users;
         QHash<QString, bool> m_loggedAccounts;
-        KEMailSettings* m_kEmailSettings;
+        KEMailSettings m_kEmailSettings;
 };
 
 QDebug operator<<(QDebug debug, AccountModel::Role role);
